# Generated by Django 2.1.2 on 2018-11-20 04:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('rest_framework_apicontrol', '0008_loggingevent_logging_group'),
    ]

    operations = [
        migrations.AddField(
            model_name='loggingevent',
            name='origin',
            field=models.CharField(choices=[('auto', 'auto'), ('user', 'user'), ('rest', 'rest')], default='auto', max_length=128),
        ),
    ]
