# Generated by Django 2.1.2 on 2018-11-20 02:54

from django.db import migrations, models
import rest_framework_apicontrol.utils


class Migration(migrations.Migration):

    dependencies = [
        ('rest_framework_apicontrol', '0005_loggingevent_logginggroup'),
    ]

    operations = [
        migrations.AddField(
            model_name='logginggroup',
            name='code',
            field=models.CharField(default=rest_framework_apicontrol.utils.generate_random_code, max_length=128),
        ),
    ]
