# Generated by Django 2.0.3 on 2018-03-28 01:52

from django.conf import settings
import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import uuid


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('rest_framework_apicontrol', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='organizationalunit',
            old_name='unit_type',
            new_name='organizational_unit_type',
        ),
        migrations.AddField(
            model_name='app',
            name='description',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='app',
            name='metadata',
            field=django.contrib.postgres.fields.jsonb.JSONField(default={}),
        ),
        migrations.AddField(
            model_name='app',
            name='owner',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='app',
            name='unique_id',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='organizationalunit',
            name='unique_id',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='organizationalunittype',
            name='created_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AddField(
            model_name='organizationalunittype',
            name='unique_id',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='organizationalunittype',
            name='updated_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AddField(
            model_name='responsible',
            name='app',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='rest_framework_apicontrol.App'),
        ),
        migrations.AddField(
            model_name='responsible',
            name='unique_id',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AlterField(
            model_name='app',
            name='created_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name='app',
            name='name',
            field=models.CharField(blank=True, max_length=128),
        ),
        migrations.AlterField(
            model_name='app',
            name='updated_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name='organizationalunit',
            name='created_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name='organizationalunit',
            name='description',
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name='organizationalunit',
            name='name',
            field=models.CharField(max_length=128),
        ),
        migrations.AlterField(
            model_name='organizationalunit',
            name='updated_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name='organizationalunittype',
            name='app',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='rest_framework_apicontrol.App'),
        ),
        migrations.AlterField(
            model_name='organizationalunittype',
            name='description',
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name='organizationalunittype',
            name='name',
            field=models.CharField(max_length=128),
        ),
        migrations.AlterField(
            model_name='responsible',
            name='created_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name='responsible',
            name='email',
            field=models.EmailField(max_length=254),
        ),
        migrations.AlterField(
            model_name='responsible',
            name='name',
            field=models.CharField(blank=True, default='RESPONSIBLE', max_length=128),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='responsible',
            name='updated_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterUniqueTogether(
            name='responsible',
            unique_together={('email', 'app')},
        ),
    ]
