# Generated by Django 2.0.3 on 2018-04-03 05:12

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('rest_framework_apicontrol', '0002_auto_20180328_0152'),
    ]

    operations = [
        migrations.AlterField(
            model_name='app',
            name='metadata',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, default={}),
        ),
    ]
