# Generated by Django 2.1.2 on 2018-11-20 03:18

from django.db import migrations, models
import django.db.models.deletion
import rest_framework_apicontrol.utils


class Migration(migrations.Migration):

    dependencies = [
        ('rest_framework_apicontrol', '0007_create_default_logging_group'),
    ]

    operations = [
        migrations.AddField(
            model_name='loggingevent',
            name='logging_group',
            field=models.ForeignKey(default=rest_framework_apicontrol.utils.get_default_logging_group, on_delete=django.db.models.deletion.CASCADE, related_name='events', to='rest_framework_apicontrol.LoggingGroup'),
        ),
    ]
